@@ -114,39 +114,33 @@ bool CInstrumenter::on_event(PyFrameObject& frame, int what, PyObject*)
     {
     case PyTrace_CALL:
     {
-        const PyCodeObject& code = *frame.f_code;
-        bool success = try_region_begin(reinterpret_cast<std::uintptr_t>(&code));
+        PyCodeObject* code = frame.f_code;
+        bool success = try_region_begin(code);
         if (!success)
         {
-            const char* name = PyUnicode_AsUTF8(code.co_name);
-            const char* module_name = get_module_name(frame);
-            assert(name);
-            assert(module_name);
-            // TODO: Use string_view/CString comparison?
-            if (std::string(name) != "_unsetprofile" && std::string(module_name, 0, 6) != "scorep")
+            std::string_view name = compat::get_string_as_utf_8(code->co_name);
+            std::string_view module_name = get_module_name(frame);
+            if (name.compare("_unsetprofile") != 0 && module_name.compare(0, 6, "scorep") != 0)
             {
-                const int line_number = code.co_firstlineno;
+                const int line_number = code->co_firstlineno;
                 const std::string file_name = get_file_name(frame);
-                region_begin(name, module_name, file_name, line_number,
-                             reinterpret_cast<std::uintptr_t>(&code));
+                region_begin(name, module_name, file_name, line_number, code);
             }
         }
         break;
     }
     case PyTrace_RETURN:
     {
-        const PyCodeObject& code = *frame.f_code;
-        bool success = try_region_end(reinterpret_cast<std::uintptr_t>(&code));
+        PyCodeObject* code = frame.f_code;
+        bool success = try_region_end(code);
         if (!success)
         {
-            const char* name = PyUnicode_AsUTF8(code.co_name);
-            const char* module_name = get_module_name(frame);
-            assert(name);
-            assert(module_name);
+            std::string_view name = compat::get_string_as_utf_8(code->co_name);
+            std::string_view module_name = get_module_name(frame);
             // TODO: Use string_view/CString comparison?
             if (std::string(name) != "_unsetprofile" && std::string(module_name, 0, 6) != "scorep")
             {
-                region_end(name, module_name, reinterpret_cast<std::uintptr_t>(&code));
+                region_end(name, module_name, code);
             }
         }
         break;
