@@ -6,6 +6,8 @@
 #include <scorep/SCOREP_User_Functions.h>
 #include <scorep/SCOREP_User_Variables.h>
 
+#include "compat.hpp"
+
 namespace scorepy
 {
 
@@ -29,7 +31,7 @@ constexpr region_handle uninitialised_region_handle = region_handle();
 
 /// Combine the arguments into a region name
 /// Return value is a statically allocated string to avoid memory (re)allocations
-inline const std::string& make_region_name(const std::string& module_name, const std::string& name)
+inline const std::string& make_region_name(std::string_view& module_name, std::string_view& name)
 {
     static std::string region;
     region = module_name;
@@ -38,12 +40,12 @@ inline const std::string& make_region_name(const std::string& module_name, const
     return region;
 }
 
-extern std::unordered_map<std::uintptr_t, region_handle> regions;
+extern std::unordered_map<compat::PyCodeObject*, region_handle> regions;
 
 /** tries to enter a region. Return true on success
  *
  */
-inline bool try_region_begin(std::uintptr_t identifier)
+inline bool try_region_begin(compat::PyCodeObject* identifier)
 {
     auto it = regions.find(identifier);
     if (it != regions.end())
@@ -57,16 +59,16 @@ inline bool try_region_begin(std::uintptr_t identifier)
     }
 }
 
-void region_begin(const std::string& function_name, const std::string& module,
+void region_begin(std::string_view& function_name, std::string_view& module,
                   const std::string& file_name, const std::uint64_t line_number,
-                  const std::uintptr_t& identifier);
-void region_begin(const std::string& function_name, const std::string& module,
+                  compat::PyCodeObject* identifier);
+void region_begin(std::string_view& function_name, std::string_view& module,
                   const std::string& file_name, const std::uint64_t line_number);
 
 /** tries to end a region. Return true on success
  *
  */
-inline bool try_region_end(std::uintptr_t identifier)
+inline bool try_region_end(compat::PyCodeObject* identifier)
 {
     auto it_region = regions.find(identifier);
     if (it_region != regions.end())
@@ -80,9 +82,9 @@ inline bool try_region_end(std::uintptr_t identifier)
     }
 }
 
-void region_end(const std::string& function_name, const std::string& module,
-                const std::uintptr_t& identifier);
-void region_end(const std::string& function_name, const std::string& module);
+void region_end(std::string_view& function_name, std::string_view& module,
+                compat::PyCodeObject* identifier);
+void region_end(std::string_view& function_name, std::string_view& module);
 
 void region_end_error_handling(const std::string& region_name);
 
